Learn R Programming

encode (version 0.3.7)

encode.character: Encode Character.

Description

Encodes character. If sep is NULL, it is replaced with the first of these that is not otherwise present in the result: /|:~!@#$

Usage

# S3 method for character
encode(x, labels = NULL, sep = NULL, ...)

Value

character

Arguments

x

object

labels

same length as x if supplied

sep

a single character not present in x or labels

...

passed arguments

See Also

Other encode: encode(), encode.default(), encode.list()