powered by
Encodes character. If sep is NULL, it is replaced with the first of these that is not otherwise present in the result: /|:~!@#$
sep
# S3 method for character encode(x, labels = NULL, sep = NULL, ...)
character
object
same length as x if supplied
a single character not present in x or labels
passed arguments
Other encode: encode(), encode.default(), encode.list()
encode()
encode.default()
encode.list()